summaryrefslogtreecommitdiffstats
path: root/kpoker/kpaint.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kpoker/kpaint.cpp')
-rw-r--r--kpoker/kpaint.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kpoker/kpaint.cpp b/kpoker/kpaint.cpp
index c6322aee..83012ab0 100644
--- a/kpoker/kpaint.cpp
+++ b/kpoker/kpaint.cpp
@@ -16,8 +16,8 @@
// QT includes
-#include <qdir.h>
-#include <qlayout.h>
+#include <tqdir.h>
+#include <tqlayout.h>
// KDE includes
//#include <kglobal.h>
@@ -34,12 +34,12 @@
// class CardImages
-QPixmap *CardImages::m_cardPixmaps;
-QPixmap *CardImages::m_deck;
+TQPixmap *CardImages::m_cardPixmaps;
+TQPixmap *CardImages::m_deck;
-CardImages::CardImages(QWidget* parent, const char* name)
- : QWidget(parent, name)
+CardImages::CardImages(TQWidget* parent, const char* name)
+ : TQWidget(parent, name)
{
m_cardPixmaps = new QPixmap[numCards];
m_deck = new QPixmap;
@@ -58,7 +58,7 @@ CardImages::~CardImages()
}
-QPixmap *
+TQPixmap *
CardImages::getCardImage(int card) const
{
if (card == 0)
@@ -71,10 +71,10 @@ CardImages::getCardImage(int card) const
// Load all the card images from the directory 'cardDir'.
void
-CardImages::loadCards(QString cardDir)
+CardImages::loadCards(TQString cardDir)
{
for (int i = 0; i < numCards; i++) {
- QString card = KCardDialog::getCardPath(cardDir, i + 1);
+ TQString card = KCardDialog::getCardPath(cardDir, i + 1);
if (card.isEmpty() || !m_cardPixmaps[i].load(card)) {
if (!card.isEmpty())
@@ -91,7 +91,7 @@ CardImages::loadCards(QString cardDir)
// Load the backside of the card deck from the file name in 'path'.
void
-CardImages::loadDeck(QString path)
+CardImages::loadDeck(TQString path)
{
if (!m_deck->load(path)) {
kdWarning() << "Could not load deck - loading default deck" << endl;
@@ -109,13 +109,13 @@ CardImages::loadDeck(QString path)
extern CardImages *cardImages;
-CardWidget::CardWidget( QWidget *parent, const char *name )
- : QPushButton( parent, name )
+CardWidget::CardWidget( TQWidget *parent, const char *name )
+ : TQPushButton( parent, name )
{
m_held = false;
setBackgroundMode( NoBackground ); // disables flickering
- connect(this, SIGNAL(clicked()), this, SLOT(ownClick()));
+ connect(this, TQT_SIGNAL(clicked()), this, TQT_SLOT(ownClick()));
setFixedSize(cardWidth, cardHeight);
}
@@ -161,8 +161,8 @@ void CardWidget::paintCard(int cardType)
m_pm = cardImages->getCardImage(card);
#endif
- // Set the pixmap in the QPushButton that we inherit from.
- if ( m_pm->size() != QSize( 0, 0 ) ) { // is an image loaded?
+ // Set the pixmap in the TQPushButton that we inherit from.
+ if ( m_pm->size() != TQSize( 0, 0 ) ) { // is an image loaded?
setPixmap(*m_pm);
}
}
@@ -173,8 +173,8 @@ void CardWidget::repaintDeck()
setPixmap(*m_pm);
setFixedSize(cardImages->getWidth(), cardImages->getHeight());
- ((QWidget*) parent())->layout()->invalidate();
- ((QWidget*) parent())->setFixedSize( ((QWidget*) parent())->sizeHint());
+ ((TQWidget*) parent())->layout()->invalidate();
+ ((TQWidget*) parent())->setFixedSize( ((TQWidget*) parent())->sizeHint());
}